The function evaluates integrals used to compute the components of OBRE a vector.
OBREnvAComputation(
nvData,
nTheta1,
nTheta2,
lDensityExpr,
nCParOBRE,
matA,
nvA
)The OBRE a vector.
The vector of data.
The first parameter.
The second parameter.
The list of symbolic expressions of density, cumulative and derivatives.
OBRE c parameter.
OBRE matrix A.
OBRE vector a.